@@ -29,7 +29,7 @@ sub transform_to_plain {
     my ($before, $after) = $m->subtexts(qw(before after));
     s/^\s+//, s/\s+$// for ($before, $after);
     if ($m->submatches->{op}->text =~ /=$/) {
-      $after = '$_ = '.$after;
+      $after = '($_ = '.$after.')';
     }
     $m->replace_text('(map +(defined($_) ? $_ : '.$after.'), '.$before.')[0]');
   };
@@ -39,10 +39,36 @@ sub transform_to_plain {
     [ after => '(?>(?&PerlPrefixPostfixTerm))' ],
   ] => $tf);
   $top->each_match_within(Assignment => [
-    [ before => '(?>(?&PerlPrefixPostfixTerm))' ],
+    [ before => '(?>(?&PerlConditionalExpression))' ],
     [ op => '(?>(?&PerlOWS) //=)' ], '(?>(?&PerlOWS))',
-    [ after => '(?>(?&PerlPrefixPostfixTerm))' ],
+    [ after => '(?>(?&PerlConditionalExpression))' ],
   ] => $tf);
 }
 
+sub check_bail_out_early {
+  my ($self, $top) = @_;
+  $top->text !~ m, // ,xs;
+}
+
 1;
+__END__
+
+=head1 NAME
+
+Babble::Plugin::DefinedOr - Plugin for defined-or (//) syntax
+
+=head1 SYNOPSIS
+
+Converts usage of the defined-or syntax from
+
+    $foo // $bar
+
+to
+
+    (map +(defined($_) ? $_ : $bar), $foo)[0]
+
+=head1 SEE ALSO
+
+L<E<sol>E<sol> syntax|Syntax::Construct/"//">
+
+=cut
